@@ -1,23 +1,4 @@
 
-#' Create Rich Command Line Applications
-#'
-#' Create rich command line applications, with colors, headings, lists,
-#' alerts, progress bars, etc. It uses CSS for theming.
-#'
-#' See [themes] for theming, [containers] for container elements,
-#' [inline-markup] for more about command substitution and inline markup.
-#'
-#' See also the various CLI elements:
-#' * Text elements: [cli_text()], [cli_verbatim()], [cli_h1()].
-#' * Containers: [cli_div()], [cli_par()], [cli_end()].
-#' * Lists: [cli_ul()], [cli_ol()], [cli_dl()], [cli_it()].
-#' * Alerts: [cli_alert()].
-#' * Progress bars: [cli_progress_bar()].
-#' 
-#' @docType package
-#' @name cliapp
-"_PACKAGE"
-
 cliappenv <- new.env()
 cliappenv$stack <- list()
 cliappenv$pid <- Sys.getpid()
@@ -36,8 +17,8 @@ cliappenv$pid <- Sys.getpid()
 #'
 #' `default_app` returns the default app, the one on the top of the stack.
 #'
-#' @param theme Theme to use, passed to the [cliapp] initializer.
-#' @param output How to print the output, passed to [cliapp] initializer.
+#' @param theme Theme to use, passed to the cliapp initializer.
+#' @param output How to print the output, passed to cliapp initializer.
 #' @param .auto_close Whether to stop the app, when the calling frame
 #'   is destroyed.
 #' @param .envir The environment to use, instead of the calling frame,
