@@ -52,3 +52,11 @@ strrep <- function(x, times) {
 
   unlist(r, use.names = FALSE)
 }
+
+is_cran_check <- function() {
+  if (identical(Sys.getenv("NOT_CRAN"), "true")) {
+    FALSE
+  } else {
+    Sys.getenv("_R_CHECK_PACKAGE_NAME_", "") != ""
+  }
+}
